pitchtools.calculate_harmonic_counterpoint_interval
===================================================

.. autofunction:: abjad.tools.pitchtools.calculate_harmonic_counterpoint_interval.calculate_harmonic_counterpoint_interval
   :noindex:
